@@ -58,17 +58,16 @@ class Worker(object):
         self.commands = None
 
     def _work(self):
-        task = self.application.db.get("SELECT * FROM task LIMIT 1")
-        print "_work", task
+        self.task = task = self.application.db.get("SELECT * FROM task LIMIT 1")
         if task:
-            push = self.task["push_id"]
-            branch = self.task["branch_name"]
-            commit = self.task["push_commit"]
+            push = task["push_id"]
+            branch = task["branch_name"]
+            commit = task["push_commit"]
 
             self.commands = ["git checkout .", "git checkout %s" % branch, "git pull origin %s" % branch,
                              "git checkout %s" % commit, self._get_local_commands]
 
-            self.application.db.udpate("UPDATE push SET started = DATETIME('NOW') WHERE id = ?", push)
+            self.application.db.update("UPDATE push SET started = DATETIME('NOW') WHERE id = ?", push)
             self.application.enqueue(self._next_command)
         else:
             self.application.enqueue(self._work)
@@ -130,12 +129,12 @@ class Worker(object):
         self.application.enqueue(self._work)
 
     def _fail(self, reason=None):
-        self.application.db.udpate("UPDATE push SET status = ?, completed = DATETIME('NOW') WHERE id = ?",
+        self.application.db.update("UPDATE push SET status = ?, completed = DATETIME('NOW') WHERE id = ?",
                                    STATUS_FAILED, self.task["push_id"])
         self._complete()
 
     def _success(self):
-        self.application.db.udpate("UPDATE push SET status = ?, completed = DATETIME('NOW') WHERE id = ?",
+        self.application.db.update("UPDATE push SET status = ?, completed = DATETIME('NOW') WHERE id = ?",
                                    STATUS_OK, self.task["push_id"])
         self._complete()
 
